#
# spec file for package python-Js2Py
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Js2Py
Version:        0.74
Release:        5.1
Summary:        JavaScript to Python Translator & JavaScript interpreter
License:        MIT
URL:            https://github.com/PiotrDabkowski/Js2Py
Source:         https://files.pythonhosted.org/packages/source/J/Js2Py/Js2Py-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/PiotrDabkowski/Js2Py/master/LICENSE.md
# PATCH-FIX-OPENSUSE remove-python-six.patch
Patch0:         remove-python-six.patch
# PATCH-FIX-UPSTREAM python312.patch gh#PiotrDabkowski/Js2Py#327
Patch1:         python312.patch
# PATCH-FIX-UPSTREAM CVE-2024-28397.patch gh#PiotrDabkowski/Js2Py#323
Patch2:         CVE-2024-28397.patch
# PATCH-FIX-UPSTREAM 313-compatibility.patch gh#PiotrDabkowski/Js2Py#334 mcepl@suse.com
# Compatibility with Python 3.13
Patch3:         313-compatibility.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyjsparser}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pyjsparser
Requires:       python-tzlocal
BuildArch:      noarch
%python_subpackages

%description
Translates JavaScript to Python code. Js2Py is able to translate and
execute virtually any JavaScript code. Js2Py, basically an
implementation of the JavaScript core, is written in pure Python.

%prep
%autosetup -p1 -n Js2Py-%{version}
cp %{SOURCE1} .

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
pushd tests
touch node_failed.txt
%{python_expand #
PYTHONPATH=%{buildroot}%{$python_sitelib} $python run.py
}
popd

%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/js2py
%{python_sitelib}/[Jj]s2[Pp]y-%{version}.dist-info

%changelog
* Fri Jun 27 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Wed Jan  1 2025 Matej Cepl <mcepl@cepl.eu>
- Add 313-compatibility.patch (gh#PiotrDabkowski/Js2Py#334)
* Mon Jul  1 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add CVE-2024-28397.patch upstream patch.
  (bsc#1226660, gh#PiotrDabkowski/Js2Py#323)
* Mon Jul  1 2024 Daniel Garcia <daniel.garcia@suse.com>
- Run tests
- Add patches:
  * remove-python-six.patch, to remove python-six dependency
  * python312.patch, to make it compatible with python312
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Thu Dec  1 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.74
  * remove template and opname not supported in old python version
  * support python 3.11 bytecode, fixes #282
* Tue May 24 2022 Alberto Planas Dominguez <aplanas@suse.com>
- Update to version 0.71
  * Some small fixes
* Fri Apr 17 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.70
  * fix error messages
* Thu Mar 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.68
  * fix error msg from python function
  * Fix print functions and a python2 only import
* Mon Jan 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.67
  * small bugfixes
* Fri Jul 26 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.66
  * Convert exponential numbers to string
  * Fix inconsistency between py2 and py3 jsdtoa
  * fix object initialized too early case
  * Try to add Python 3.7 and 3.8 (dev).
  * Drop support for unsupported Python versions.
* Thu Mar 14 2019 Jan Engelhardt <jengelh@inai.de>
- Remove wrong statements from description.
* Wed Mar 13 2019 Ondřej Súkup <mimi.vx@gmail.com>
- initial commit
